

# Path of the Asp-thr subsystem
# setwd("C:/Users/millard/Downloads/Data fluxes/Sup_code_dev/Asp-Thr")

# Leaf & Plant to analyze

# SELECT the experiment:
#    - sleaf: age of the leaf (3, 7, 11 or 15 days)
#    - splant: plant (A, B or C)

sleaf <- "L15"
splant <- "A"



########################
### CREATE WORKSPACE ###
########################

# Load R packages
library(vioplot)
library(devtools)
library(readxl)
library(tidyr)
library(plyr)
library(reshape2)

# Get current directory
wd <- getwd()

# Load IsoSim
setwd(file.path(dirname(wd), "isosim_v2.0.0", "isosim"))
source("nlsic.R")
source("isosim.R")

#################
### LOAD DATA ###
#################

# Get data

replicate <- paste(splant, sleaf, sep="")

# Go back to working directory and create "res" folder to store the results
setwd(wd)
if (!file.exists(replicate)){
  dir.create(file.path(wd, replicate))
}

# measurement times (in min)
times <- c(0,30,60,120)

# go to data directory
setwd(file.path(dirname(wd), "data"))

# load 15N-enrichments of amino acids
df <- read_excel("AA_labeling.xlsx")
data_input <- subset.data.frame(df1, plant == splant & leaf == sleaf)
data_input <- subset.data.frame(data_input, select= c(-plant,-leaf,-time))
data_input <- subset.data.frame(data_input, select= c(asp_1,thr_1))
data_input <- as.matrix(sapply(data_input, as.numeric)) 
data_input

# load concentrations of amino acids
AAconc <- read_excel("AA_concentrations.xlsx", sheet = "for R")
AAconcm<- subset.data.frame(AAconc, plant == splant & leaf == sleaf & type == "mean")
AAconcm <- subset.data.frame(AAconcm, select=c(-plant,-leaf,-type))
for (i in 1:5){
  AAconcm[,i] <- as.numeric(as.character(AAconcm[,i]))
}
AAconcm

AAconcsd<- subset.data.frame(AAconc, plant == splant & leaf == sleaf & type == "SD")
AAconcsd <- subset.data.frame(AAconcsd, select=c(-plant,-leaf,-type))
for (i in 1:5){
  AAconcsd[,i] <- as.numeric(as.character(AAconcsd[,i]))
}
AAconcsd


########################
### CALCULATE FLUXES ###
########################

setwd(file.path(wd, replicate))

# fit labeling dynamics of metabolic intermediates
enr_in <- fit_label_input(data_input, t=times, file=paste("res_fit_enr_", replicate, sep=""), mc.cores=detectCores())

#If the subsystem is not working
#Rtools path loading
#Sys.setenv(PATH = paste("C:/Rtools/bin", Sys.getenv("PATH"), sep=";"))

# define subsystem
s1 = list(name = "fitthr",
            rxn_subnet = list(r1    = list("R"=c("asp", "thr"),         "C"=c(-1, 1),     "E"="Vthr",      "T"=c("A", "A")),
                              rout  = list("R"=c("thr"),                "C"=c(-1),        "E"="Vthr",      "T"=("A"))),
            meta_conc_subnet = c("asp"=1, "thr"=AAconcm[["thr"]]),
            kp_subnet = c("Vthr"=1),
            te_subnet = c("Vthr"),
            te_upc_subnet = c("Vthr"=1e2),
            te_loc_subnet = c("Vthr"=1e-6),
            sd_meas = list(conc=AAconcsd[["thr"]], iso=0.02),
            times = times,
            enr_in = enr_in,
            anFun = NULL,
            niter = 4,
            mc.cores = NULL,
            data_meas_subnet = list(conc=(AAconcm[["thr"]]), iso=cbind(times, "thr_1"=data_input[,"thr_1"])))
  
# calculate fluxes
res_sub <- fit_subsystems(s1, dirname=paste("fit_", replicate, ".txt", sep=""), mc.cores=detectCores())

# get summary
list2file(res_sub$summary, file=paste("summary_", replicate, ".txt", sep=""))

setwd(file.path(wd))

